@@ -1,4 +1,5 @@
 
+from docker_registry.core import compat
 from docker_registry.core import driver
 from docker_registry.core import exceptions
 from docker_registry.core import lru
@@ -11,6 +12,7 @@ import logging
 from jss.connection import JssClient
 
 logger = logging.getLogger(__name__)
+json = compat.json
 
 class Storage(driver.Base):
 
@@ -38,6 +40,14 @@ class Storage(driver.Base):
         
         return object_instance.generate_url("GET")
     
+    def get_json(self, path):
+        logger.info("get_json path:%s" % path)
+        try:
+            return json.loads(self.get_unicode(path))
+        except Exception as e:
+            logger.error("get_json error:%s" % e)
+            return []
+        
     @lru.get
     def get_content(self, path):
         logger.info("get_content path:%s" % path)
